# xlsx_compare
Forked from XLSXwriter

A package that extracts some test helper functions from XLSXwriter for external use. The script provies the ability to compare the equivalency of two Excel documents.